@@ -83,10 +83,7 @@ def autodoc_skip(app, what, name, obj, skip, options):
 # -- Intersphinx --------------------------------------------------------------
 
 intersphinx_mapping = {
-    'python': ('http://docs.python.org/', None),
-    'ftrack': (
-        'http://rtd.ftrack.com/docs/ftrack/en/stable/', None
-    )
+    'python': ('http://docs.python.org/', None)
 }
 
 
