@@ -71,6 +71,7 @@ def event_hub(request, session):
     hub = ftrack_api.event.hub.EventHub(
         session.server_url, session.api_user, session.api_key
     )
+
     hub.connect()
 
     def cleanup():
@@ -589,6 +590,39 @@ def test_synchronous_publish(event_hub):
     assert results == ['A', 'B', 'C']
 
 
+def test_publish_during_connect(session, mocker):
+    '''Test publishing while connection is initialising.'''
+    event_hub = ftrack_api.event.hub.EventHub(
+        session.server_url, session.api_user, session.api_key
+    )
+
+    def replier(event):
+        '''Replier.'''
+        return 'Replied'
+
+    event_hub.subscribe('topic=test', replier)
+    called = {'callback': None}
+
+    def on_reply(event):
+        called['callback'] = event['data']
+
+    # Mark the connection as initialised.
+    event_hub.init_connection()
+
+    event_hub.publish(
+        Event(topic='test'), on_reply=on_reply
+    )
+
+    assert event_hub._event_send_queue.qsize() == 1
+
+    event_hub.connect()
+    event_hub.wait(2)
+
+    assert called['callback'] == 'Replied'
+
+    assert event_hub._event_send_queue.qsize() == 0
+
+
 def test_publish_with_reply(event_hub):
     '''Publish asynchronous event with on reply handler.'''
 
